@@ -42,3 +42,19 @@ impl<T> Drop for Closure<T> {
         })(self);
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::Arc;
+    use std::{ptr::null, thread::spawn};
+
+    #[test]
+    fn send() {
+        let closure = Arc::new(Closure::new(null(), ()));
+
+        spawn(move || {
+            closure.entry_function();
+        });
+    }
+}
